@@ -13,6 +13,8 @@ pub enum Value {
     Uuid(Uuid),
     /// 'string value'
     SingleQuotedString(String),
+    /// N'string value'
+    NationalStringLiteral(String),
     /// Boolean value true or false,
     Boolean(bool),
     /// Date value
@@ -34,6 +36,7 @@ impl ToString for Value {
             Value::Double(v) => v.to_string(),
             Value::Uuid(v) => v.to_string(),
             Value::SingleQuotedString(v) => format!("'{}'", v),
+            Value::NationalStringLiteral(v) => format!("N'{}'", v),
             Value::Boolean(v) => v.to_string(),
             Value::Date(v) => v.to_string(),
             Value::Time(v) => v.to_string(),
